heat1d package
==============

Submodules
----------

heat1d.cli module
-----------------

.. automodule:: heat1d.cli
   :members:
   :undoc-members:
   :show-inheritance:

heat1d.main module
------------------

.. automodule:: heat1d.main
   :members:
   :undoc-members:
   :show-inheritance:

heat1d.orbits module
--------------------

.. automodule:: heat1d.orbits
   :members:
   :undoc-members:
   :show-inheritance:

heat1d.prettyPlots module
-------------------------

.. automodule:: heat1d.prettyPlots
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: heat1d
   :members:
   :undoc-members:
   :show-inheritance:
